Month enum
Values
- january → const Month
-
const Month('January', 'Jan') - february → const Month
-
const Month('February', 'Feb') - march → const Month
-
const Month('March', 'Mar') - april → const Month
-
const Month('April', 'Apr') - may → const Month
-
const Month('May', 'May') - june → const Month
-
const Month('June', 'Jun') - july → const Month
-
const Month('July', 'Jul') - august → const Month
-
const Month('August', 'Aug') - september → const Month
-
const Month('September', 'Sep') - october → const Month
-
const Month('October', 'Oct') - november → const Month
-
const Month('November', 'Nov') - december → const Month
-
const Month('December', 'Dec')
Properties
- abbreviation → String
-
final
- completeName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited